SpanishCardinalCodec class final
Converts integers to and from Spanish cardinal numerals.
Formatting emits normalized masculine standalone Spanish cardinal text.
Parsing accepts common accentless spellings and un / uno variants.
Constructors
- SpanishCardinalCodec()
-
Creates a Spanish cardinal codec.
const
Properties
-
decoder
→ Converter<
String, int> -
Converts display strings into numeric values.
no setterinherited
-
encoder
→ Converter<
int, String> -
Converts numeric values into display strings.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
String, int> -
Inverts
this.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
String encoded) → int -
Alias for parse.
inherited
-
encode(
int input) → String -
Alias for format.
inherited
-
format(
num value) → String -
Formats
valueinto a display string.override -
fuse<
R> (Codec< String, R> other) → Codec<int, R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String input) → int -
Parses
inputand returns the numeric value.override -
toString(
) → String -
A string representation of this object.
inherited
-
tryParse(
String input) → int? -
Parses
input, returningnullinstead of throwing FormatException.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited