FrenchNumerals class final
French numerals language pack.
- Implemented types
Constructors
- FrenchNumerals()
-
Creates a French numerals language pack.
const
Properties
- compactUnits → NumeralUnitSet
-
Compact unit data for this language.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → String
-
BCP 47-style locale identifier.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cardinal(
) → FrenchCardinalCodec - Creates a French cardinal number codec.
-
compact(
{String decimalSeparator = ',', int minFractionDigits = 0, int maxFractionDigits = 2, bool trimTrailingZeros = true, Rounding rounding = Rounding.halfUp, bool compactOverflow = true}) → CompactCodec -
Creates a compact number codec using this pack's units.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
year(
{String suffix = ''}) → FrenchYearCodec - Creates a French year number codec.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited