zh library
Simplified Chinese numerals language pack.
Classes
- ChineseCardinalCodec
- Converts integers to and from Simplified Chinese cardinal numerals.
- ChineseFinancialCodec
- Converts integers to and from Simplified Chinese financial numerals.
- ChineseNumerals
- Simplified Chinese numerals language pack.
- ChineseRmbCodec
- Converts RMB amounts to and from Simplified Chinese uppercase amount text.
- ChineseYearCodec
- Converts years to and from Simplified Chinese digit-by-digit numerals.
Constants
- chineseCompactUnits → const NumeralUnitSet
-
Simplified Chinese compact units:
万,亿,兆. - zh → const ChineseNumerals
- Simplified Chinese numerals language pack.
Functions
-
cardinal(
) → ChineseCardinalCodec - Creates a Simplified Chinese cardinal number codec.
-
compact(
{String decimalSeparator = '.', int minFractionDigits = 0, int maxFractionDigits = 2, bool trimTrailingZeros = true, Rounding rounding = Rounding.halfUp, bool compactOverflow = true}) → CompactCodec - Creates a Simplified Chinese compact number codec.
-
financial(
) → ChineseFinancialCodec - Creates a Simplified Chinese financial numeral codec.
-
rmb(
{String prefix = '人民币', String wholeSuffix = '整', bool writeWholeSuffixForJiao = false}) → ChineseRmbCodec - Creates a Simplified Chinese RMB amount codec.
-
year(
{String suffix = ''}) → ChineseYearCodec - Creates a Simplified Chinese year number codec.