ChineseFinancialCodec class final

Converts integers to and from Simplified Chinese financial numerals.

Inheritance

Constructors

ChineseFinancialCodec()
Creates a Simplified Chinese financial numeral codec.
const

Properties

allowImplicitOneForSmallUnit → bool
finalinherited
allowTrailingUnitOmission → bool
finalinherited
decoder → Converter<String, int>
Converts display strings into numeric values.
no setterinherited
digitSymbols → List<String>
finalinherited
digitValues → Map<String, int>
finalinherited
encoder → Converter<int, String>
Converts numeric values into display strings.
no setterinherited
expectedDescription → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<String, int>
Inverts this.
no setterinherited
omitLeadingOneForTen → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionUnits → List<String>
finalinherited
sectionUnitValues → Map<String, int>
finalinherited
smallUnits → List<String>
finalinherited
smallUnitValues → Map<String, int>
finalinherited
unexpectedDescription → String
finalinherited

Methods

decode(String encoded) → int
Alias for parse.
inherited
encode(int input) → String
Alias for format.
inherited
format(num value) → String
Formats value into a display string.
inherited
fuse<R>(Codec<String, R> other) → Codec<int, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String input) → int
Parses input and returns the numeric value.
inherited
toString() → String
A string representation of this object.
inherited
tryParse(String input) → int?
Parses input, returning null instead of throwing FormatException.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

digits → const List<String>