wholeSuffix property
Suffix written when the amount has no lower unit.
Common values are 整 and 正.
Implementation
final String wholeSuffix;
Suffix written when the amount has no lower unit.
Common values are 整 and 正.
final String wholeSuffix;