TraditionalChineseCardinalCodec class final

Converts integers to and from Traditional Chinese cardinal numerals.

Formatting emits normalized Traditional Chinese text. Parsing also accepts common Simplified Chinese characters and variants.

Inheritance

Constructors

TraditionalChineseCardinalCodec()
Creates a Traditional Chinese cardinal codec.
const

Properties

decoder Converter<String, int>
Converts display strings into numeric values.
no setterinherited
encoder Converter<int, String>
Converts numeric values into display strings.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
inverted Codec<String, int>
Inverts this.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(String encoded) int
Alias for parse.
inherited
encode(int input) String
Alias for format.
inherited
format(num value) String
Formats value into a display string.
override
fuse<R>(Codec<String, R> other) Codec<int, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String input) int
Parses input and returns the numeric value.
override
toString() String
A string representation of this object.
inherited
tryParse(String input) int?
Parses input, returning null instead of throwing FormatException.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited