parse method
Parses input and returns the numeric value.
Throws FormatException when input cannot be parsed by this codec.
Implementation
@override
int parse(String input) => _delegate.parse(_toSimplified(input));
Parses input and returns the numeric value.
Throws FormatException when input cannot be parsed by this codec.
@override
int parse(String input) => _delegate.parse(_toSimplified(input));