TraditionalChineseNumerals class final

Traditional Chinese numerals language pack.

Implemented types

Constructors

TraditionalChineseNumerals()
Creates a Traditional Chinese numerals language pack.
const

Properties

compactUnits NumeralUnitSet
Compact unit data for this language.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
locale String
BCP 47-style locale identifier.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cardinal() TraditionalChineseCardinalCodec
Creates a Traditional Chinese cardinal number codec.
compact({String decimalSeparator = '.', int minFractionDigits = 0, int maxFractionDigits = 2, bool trimTrailingZeros = true, Rounding rounding = Rounding.halfUp, bool compactOverflow = true}) CompactCodec
Creates a compact number codec using this pack's units.
override
financial() TraditionalChineseFinancialCodec
Creates a Traditional Chinese financial numeral codec.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
year({String suffix = ''}) TraditionalChineseYearCodec
Creates a Traditional Chinese year number codec.

Operators

operator ==(Object other) bool
The equality operator.
inherited