ChineseNumerals class final
Simplified Chinese numerals language pack.
- Implemented types
Constructors
- ChineseNumerals()
-
Creates a Simplified Chinese numerals language pack.
const
Properties
- compactUnits → NumeralUnitSet
-
Compact unit data for this language.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → String
-
BCP 47-style locale identifier.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cardinal(
) → ChineseCardinalCodec - Creates a Simplified Chinese cardinal number codec.
-
compact(
{String decimalSeparator = '.', int minFractionDigits = 0, int maxFractionDigits = 2, bool trimTrailingZeros = true, Rounding rounding = Rounding.halfUp, bool compactOverflow = true}) → CompactCodec -
Creates a compact number codec using this pack's units.
override
-
financial(
) → ChineseFinancialCodec - Creates a Simplified Chinese financial numeral codec.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rmb(
{String prefix = '人民币', String wholeSuffix = '整', bool writeWholeSuffixForJiao = false}) → ChineseRmbCodec - Creates a Simplified Chinese RMB amount codec.
-
toString(
) → String -
A string representation of this object.
inherited
-
year(
{String suffix = ''}) → ChineseYearCodec - Creates a Simplified Chinese year number codec.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited